### 0.13.4 {small}`2025-11-12`

```{rubric} Features
```
* Added `rsc.dcg.waggr` function for decoupler-GPU {pr}`469` {smaller}`M Cheng`
* Added `rsc.dcg.zscore` function for decoupler-GPU {pr}`470` {smaller}`S Kharuk`
* Support isolated vertices in nearest neighbors graph for `tl.leiden` and `tl.louvain`.
{pr}`476` {smaller}`J Pintar`
* In `pp.neighbors` set self-distances to zero where this is definitionally required
by the metric, but non-zero distances are potentially returned by `cuvs`/`cuml` due
to FP32 rounding. {pr}`477` {smaller}`J Pintar`
* add support for `scipy sparse array` conversion with `get` {pr}`496` {smaller}`S Dicks`
